==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain.md <==
# AmazonManagedBlockchainBlockchain


```text
aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain
```

```text
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')
```



| Illustration | AmazonManagedBlockchainBlockchain | AmazonManagedBlockchainBlockchainCard | AmazonManagedBlockchainBlockchainGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain.png) | ![illustration for AmazonManagedBlockchainBlockchain](../../../aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain.Local.png) | ![illustration for AmazonManagedBlockchainBlockchainCard](../../../aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchainCard.Local.png) | ![illustration for AmazonManagedBlockchainBlockchainGroup](../../../aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchainGroup.Local.png) |




## AmazonManagedBlockchainBlockchain

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchain
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchain('AmazonManagedBlockchainBlockchain', 'Amazon Managed Blockchain Blockchain', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchain
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchain('AmazonManagedBlockchainBlockchain', 'Amazon Managed Blockchain Blockchain', 'an optional tech label')
@enduml
```

## AmazonManagedBlockchainBlockchainCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchainCard
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchainCard('AmazonManagedBlockchainBlockchainCard', 'Amazon Managed Blockchain Blockchain Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchainCard
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchainCard('AmazonManagedBlockchainBlockchainCard', 'Amazon Managed Blockchain Blockchain Card', 'an optional description')
@enduml
```

## AmazonManagedBlockchainBlockchainGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchainGroup
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchainGroup('AmazonManagedBlockchainBlockchainGroup', 'Amazon Managed Blockchain Blockchain Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchainGroup
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchainGroup('AmazonManagedBlockchainBlockchainGroup', 'Amazon Managed Blockchain Blockchain Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain.md <==
# AmazonManagedBlockchainBlockchain


```text
aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain
```

```text
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')
```



| Illustration | AmazonManagedBlockchainBlockchain | AmazonManagedBlockchainBlockchainCard | AmazonManagedBlockchainBlockchainGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain.png) | ![illustration for AmazonManagedBlockchainBlockchain](../../../aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain.Local.png) | ![illustration for AmazonManagedBlockchainBlockchainCard](../../../aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchainCard.Local.png) | ![illustration for AmazonManagedBlockchainBlockchainGroup](../../../aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchainGroup.Local.png) |




## AmazonManagedBlockchainBlockchain

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchain
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchain('AmazonManagedBlockchainBlockchain', 'Amazon Managed Blockchain Blockchain', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchain
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchain('AmazonManagedBlockchainBlockchain', 'Amazon Managed Blockchain Blockchain', 'an optional tech label')
@enduml
```

## AmazonManagedBlockchainBlockchainCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchainCard
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchainCard('AmazonManagedBlockchainBlockchainCard', 'Amazon Managed Blockchain Blockchain Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchainCard
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchainCard('AmazonManagedBlockchainBlockchainCard', 'Amazon Managed Blockchain Blockchain Card', 'an optional description')
@enduml
```

## AmazonManagedBlockchainBlockchainGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchainGroup
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchainGroup('AmazonManagedBlockchainBlockchainGroup', 'Amazon Managed Blockchain Blockchain Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonManagedBlockchainBlockchainGroup
include('aws-20210730/Resource/Blockchain/AmazonManagedBlockchainBlockchain')

' renders the element
AmazonManagedBlockchainBlockchainGroup('AmazonManagedBlockchainBlockchainGroup', 'Amazon Managed Blockchain Blockchain Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
